@@ -1,21 +1,23 @@
 ### function used to check types of available filesuffix in a directory
 
 # folder <- '~/med4_avhrr_sst2_4km'
-check_gzfiles <- function(sstring="*",folder=".",filetype=".gz")
+check_gzfiles <- function(sstring="*",folder,filetype=".gz")
 {
-  if(length(sstring) == 1){
-    if(missing(folder) | folder != F){
-      setwd(folder)
-      #files <- unlist(system(paste("find . -maxdepth 0 -name '",sstring,"' -print0 |xargs -0 ls",sep=""),intern=T))
-      files <- Sys.glob(sstring)
-    }else{files <- sstring}
-    #   files <- unlist(system(paste("ls ", sstring, sep=""),intern=TRUE))
-    files <- files[files != "dummy.gz"]
-  }else{
-    files <- sstring
+  
+  if(!missing(folder)) {
+    if(folder[1] !=F){
+      folder <- paste0(folder, "/"); folder <- gsub('//','/',folder)
+      sstring <- paste0(folder,"*",sstring)
+    }
   }
+  files <- Sys.glob(sstring)
+  ii <- tail(which(strsplit(files, "")[[1]]=="/"),1)
+  folder <- substr(files,1,ii)
+  files <- substr(files,ii+1,nchar(files))
+  files <- files[files != "dummy.gz"]
+  
   if(length(files) == 0)stop(paste0('ERROR: there is no file of the type ',sstring))
-
+  
   files <- subset(files, substr(files, nchar(files)+1-nchar(filetype), nchar(files)) == filetype)
   objs <- matrix(as.character(unlist(strsplit(files,"\\_"))),ncol=7,byrow=T)
   for (i in 1:length(objs[,7]))
